import React, { useEffect, useState } from 'react'
import { withClient, Client } from 'cozy-client'
import { translate } from 'cozy-ui/react/I18n'

import { isKonnectorRunning } from 'cozy-harvest-lib/dist/helpers/triggers'
import {
  KonnectorJob,
  ERROR_EVENT,
  LOGIN_SUCCESS_EVENT,
  SUCCESS_EVENT,
} from 'cozy-harvest-lib/dist/models/KonnectorJob'
import { Trigger } from 'doctypes'

import Lottie from 'react-lottie'
import * as loadingData from 'assets/anims/bounceloading.json'

const loadingOptions = {
  loop: true,
  autoplay: true,
  animationData: loadingData,
  rendererSettings: {
    preserveAspectRatio: 'xMidYMid slice',
  },
}

interface KonnectorLaunchProps {
  trigger: Trigger
  handleKonnectorLaunch: Function
  client: Client
  t: Function
}

const KonnectorLaunch: React.FC<KonnectorLaunchProps> = ({
  trigger,
  handleKonnectorLaunch,
  client,
  t,
}: KonnectorLaunchProps) => {
  const [state, setState] = useState<string | null>(null)

  const callbackResponse = (_state: string) => {
    setState(_state)
  }

  const handleClick = () => {
    handleKonnectorLaunch()
  }

  useEffect(() => {
    let subscribed = true
    async function getData() {
      if (subscribed && !isKonnectorRunning(trigger)) {
        const konnectorJob = new KonnectorJob(client, trigger)
        await konnectorJob.launch()
        konnectorJob.jobWatcher.on(ERROR_EVENT, () => {
          callbackResponse(ERROR_EVENT)
        })
        konnectorJob.jobWatcher.on(LOGIN_SUCCESS_EVENT, () => {
          callbackResponse(LOGIN_SUCCESS_EVENT)
        })
        konnectorJob.jobWatcher.on(SUCCESS_EVENT, () => {
          callbackResponse(SUCCESS_EVENT)
        })
      }
    }
    getData()
    return () => {
      subscribed = false
    }
  }, [])

  // TODO - SUCCESS SCREEN + rename of class
  return (
    <div className="kload-content">
      {!state ? (
        <>
          <Lottie options={loadingOptions} height={50} width={50} />
          <div className="kload-content-text kload-content-text-center text-16-normal">
            <div>{t('KONNECTORCONFIG.PLZ_WAIT')}</div>
          </div>
          <div className="kload-content-text text-16-normal">
            <div>{t('KONNECTORCONFIG.LOADING_DATA')}</div>
          </div>
        </>
      ) : (
        <>
          <div>
            {/* // Add success when state <> ERROR_EVENT 
            // Add Error when state = ERROR_EVENT */}
          </div>
        </>
      )}
    </div>
  )
}

export default translate()(withClient(KonnectorLaunch))
