'use strict'
import ConsumptionDataFormatter from '../../src/services/consumptionDataFormatterService'
import consumptionHalfHourlyData from '../__mocks__/consumptionHalfHourlyDataFormatterMock'
import consumptionDailyData from '../__mocks__/consumptionDailyDataFormatterMock'
import consumptionMonthlyData from '../__mocks__/consumptionMonthlyDataFormatterMock'
import { DateTime } from 'luxon'

import { TimeStep } from '../../src/services/dataConsumptionContracts'

describe('Consumption Data Formatter service tests', () => {
  beforeEach(() => {
    jest.resetAllMocks()
  })

  const consumptionDataFormatter = new ConsumptionDataFormatter()

  const halfHourlyData = JSON.parse(JSON.stringify(consumptionHalfHourlyData))

  const mappedHalfHourlyData = halfHourlyData.map(item => ({
    date: DateTime.fromISO(item.date),
    value: item.value,
  }))

  const dailyData = JSON.parse(JSON.stringify(consumptionDailyData))

  const mappeddailyDataData = dailyData.map(item => ({
    date: DateTime.fromISO(item.date),
    value: item.value,
  }))

  const monthlyData = JSON.parse(JSON.stringify(consumptionMonthlyData))

  const mappedMonthlyData = monthlyData.map(item => ({
    date: DateTime.fromISO(item.date),
    value: item.value,
  }))

  const dayTimePeriod = {
    startDate: DateTime.local(2018, 6, 20),
    endDate: DateTime.local(2018, 6, 20, 23, 30),
  }

  const daytimeStep = TimeStep.HALF_AN_HOUR

  const monthTimePeriod = {
    startDate: DateTime.local(2018, 7, 1),
    endDate: DateTime.local(2018, 8, 2),
  }

  const monthTimeStep = TimeStep.DAY

  const yearTimePeriod = {
    startDate: DateTime.local(2018, 7, 1),
    endDate: DateTime.local(2019, 2, 6),
  }

  const yearTimeStep = TimeStep.MONTH

  const sumReducer = (acc, dataLoad) => acc + dataLoad.value

  it('formatGraphData', () => {
    const halfHourResult = consumptionDataFormatter.formatGraphData(
      mappedHalfHourlyData,
      dayTimePeriod,
      daytimeStep
    )
    const dayResult = consumptionDataFormatter.formatGraphData(
      mappeddailyDataData,
      monthTimePeriod,
      monthTimeStep
    )
    const monthResult = consumptionDataFormatter.formatGraphData(
      mappedMonthlyData,
      yearTimePeriod,
      yearTimeStep
    )

    expect(halfHourResult.length).toBe(48)
    expect(halfHourResult.reduce(sumReducer, 0)).toBe(213.33000000000004)

    expect(dayResult.length).toBe(33)
    expect(dayResult.reduce(sumReducer, 0)).toBe(7544.85)

    expect(monthResult.length).toBe(8)
    expect(monthResult.reduce(sumReducer, 0)).toBe(50588.8)
  })
})
